define(
//begin v1.x content
({
	"descTemplate": "${2} - ${3} από ${1} ${0}",
	"firstTip": "Πρώτη σελίδα",
	"lastTip": "Τελευταία σελίδα",
	"nextTip": "Επόμενη σελίδα",
	"prevTip": "Προηγούμενη σελίδα",
	"itemTitle": "στοιχεία",
	"singularItemTitle": "στοιχείο",
	"pageStepLabelTemplate": "Σελίδα ${0}",
	"pageSizeLabelTemplate": "${0} στοιχεία ανά σελίδα",
	"allItemsLabelTemplate": "Όλα τα στοιχεία",
	"gotoButtonTitle": "Μετάβαση σε συγκεκριμένη σελίδα",
	"dialogTitle": "Μετάβαση σε σελίδα",
	"dialogIndication": "Καθορίστε τον αριθμό της σελίδας",
	"pageCountIndication": " (${0} σελίδες)",
	"dialogConfirm": "Μετάβαση",
	"dialogCancel": "Ακύρωση",
	"all": "όλα"
})
//end v1.x content
);
